;; Generated package description from ampc.el  -*- no-byte-compile: t -*-
(define-package "ampc" "0.2.0.20240201.134117" "Asynchronous Music Player Controller" '((emacs "24.3")) :commit "ada6ae982517ec17280ee639724d087e319386ef" :url "https://elpa.gnu.org/packages/ampc.html" :authors '(("Christopher Schmidt" . "christopher@ch.ristopher.com")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("ampc" "mpc" "mpd"))
